@@ -1,5 +1,5 @@
 import blazer
-from blazer.hpc.mpi import parallel, pipeline, partial as p, scatter, where, select, filter, rank, size
+from blazer.hpc.mpi import parallel, pipeline, partial as p
 from .funcs import calc_more_stuff, calc_some, calc_stuff, add_date
 
 def test_parallel():
@@ -15,5 +15,3 @@ def test_parallel():
         
         if blazer.ROOT:
             assert len(result) == len(tasks)
-
-            blazer.stop()
\ No newline at end of file
